function Aloc = STIMA_Lapl_BFE(Vertices,ElemInfo,QuadRule,varargin)

  % Initialize constants
  
  nGauss = size(QuadRule.w,1);
  
  % Preallocate memory
  
  Aloc = zeros(4,4);
    
  % Extract vertices
  
  P1 = Vertices(1,:);
  P2 = Vertices(2,:);
  P3 = Vertices(3,:);
  P4 = Vertices(4,:);
  
  for i = 1:nGauss

    % Compute element mapping PhiK and matrix M
  
    grad_N = grad_shap_BFE(QuadRule.x(i,:));  
    M(1,:) = P1(1)*grad_N(1:2)+P2(1)*grad_N(3:4) + ...
                  P3(1)*grad_N(5:6)+P4(1)*grad_N(7:8);
    M(2,:) = P1(2)*grad_N(1:2)+P2(2)*grad_N(3:4) + ...
                  P3(2)*grad_N(5:6)+P4(2)*grad_N(7:8);
    det_M = abs(det(M));
    
    % Compute gradients of element shape functions

    grad_N = reshape(grad_N, 2, 4);
    grad_N = M' \ grad_N;
        
    % Compute entries of stiffness matrix
    
    Aloc(1,1) = Aloc(1,1) + QuadRule.w(i)*dot(grad_N(:,1),grad_N(:,1))*det_M;
    Aloc(1,2) = Aloc(1,2) + QuadRule.w(i)*dot(grad_N(:,1),grad_N(:,2))*det_M;
    Aloc(1,3) = Aloc(1,3) + QuadRule.w(i)*dot(grad_N(:,1),grad_N(:,3))*det_M;
    Aloc(1,4) = Aloc(1,4) + QuadRule.w(i)*dot(grad_N(:,1),grad_N(:,4))*det_M;
    Aloc(2,2) = Aloc(2,2) + QuadRule.w(i)*dot(grad_N(:,2),grad_N(:,2))*det_M;
    Aloc(2,3) = Aloc(2,3) + QuadRule.w(i)*dot(grad_N(:,2),grad_N(:,3))*det_M;
    Aloc(2,4) = Aloc(2,4) + QuadRule.w(i)*dot(grad_N(:,2),grad_N(:,4))*det_M;
    Aloc(3,3) = Aloc(3,3) + QuadRule.w(i)*dot(grad_N(:,3),grad_N(:,3))*det_M;
    Aloc(3,4) = Aloc(3,4) + QuadRule.w(i)*dot(grad_N(:,3),grad_N(:,4))*det_M;
    Aloc(4,4) = Aloc(4,4) + QuadRule.w(i)*dot(grad_N(:,4),grad_N(:,4))*det_M;

  end
  
  % Fill in lower triangular part
  
  tri = triu(Aloc);
  Aloc = tri+tril(tri',-1);
  
return
