function lsqphi = lsqrhs(Mesh, v, FHandle, QuadRule, varargin)

    nPts = size(QuadRule.w,1);
    nCoordinates = size(Mesh.Coordinates,1);
    nElements = size(Mesh.Elements,1);
  
    % Preallocate memory

    L = zeros(nCoordinates,1);

    % Precompute shape functions

    N = shap_LFE(QuadRule.x);

    % Assemble element contributions

    for i = 1:nElements

        % Extract vertices

        vidx = Mesh.Elements(i,:);

        % Compute element mapping

        bK = Mesh.Coordinates(vidx(1),:);
        BK = [Mesh.Coordinates(vidx(2),:)-bK; Mesh.Coordinates(vidx(3),:)-bK];
        inv_BK = inv(BK);
        det_BK = abs(det(BK));

        x = QuadRule.x*BK + ones(nPts,1)*bK;

        % Compute load data

        FVal = FHandle(x,Mesh.ElemFlag(i),varargin{:});
        vvals = [v(x(1,:)), v(x(2,:)), v(x(3,:))];
        grad_N = grad_shap_LFE(QuadRule.x);

        % Add contributions to global load vector

        L(vidx(1)) = L(vidx(1)) + FVal(1) * grad_N(1,1:2) * inv_BK' * vvals(:,1) * QuadRule.w(1) * det_BK...
            + FVal(2) * grad_N(2,1:2) * inv_BK' * vvals(:,2) * QuadRule.w(2) * det_BK...
            + FVal(3) * grad_N(3,1:2) * inv_BK' * vvals(:,3) * QuadRule.w(3) * det_BK;
        L(vidx(2)) = L(vidx(2)) + FVal(1) * grad_N(1,3:4) * inv_BK' * vvals(:,1) * QuadRule.w(1) * det_BK...
            + FVal(2) * grad_N(2,3:4) * inv_BK' * vvals(:,2) * QuadRule.w(2) * det_BK...
            + FVal(3) * grad_N(3,3:4) * inv_BK' * vvals(:,3) * QuadRule.w(3) * det_BK;
        L(vidx(3)) = L(vidx(3)) + FVal(1) * grad_N(1,5:6) * inv_BK' * vvals(:,1) * QuadRule.w(1) * det_BK...
            + FVal(2) * grad_N(2,5:6) * inv_BK' * vvals(:,2) * QuadRule.w(2) * det_BK...
            + FVal(3) * grad_N(3,5:6) * inv_BK' * vvals(:,3) * QuadRule.w(3) * det_BK;

    end

    lsqphi = L;

return
